@@ -14,9 +14,9 @@ use Exporter 'import';
 use List::MoreUtils qw(uniq);
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2023-01-19'; # DATE
+our $DATE = '2023-04-06'; # DATE
 our $DIST = 'App-OrgUtils'; # DIST
-our $VERSION = '0.484'; # VERSION
+our $VERSION = '0.485'; # VERSION
 
 our @EXPORT_OK = qw(list_org_headlines);
 
@@ -26,7 +26,7 @@ my $today;
 my $yest;
 
 sub _process_hl {
-    my ($file, $hl, $args, $res) = @_;
+    my ($file, $hl, $args, $res, $is_raw) = @_;
 
     return if $args->{from_level} && $hl->level < $args->{from_level};
     return if $args->{to_level}   && $hl->level > $args->{to_level};
@@ -136,7 +136,9 @@ sub _process_hl {
         $r->{level}      = $hl->level;
         $date = $r->{due_date};
     } else {
-        if ($ats) {
+        if ($is_raw) {
+            chomp($r = $hl->header_as_string);
+        } elsif ($ats) {
             my $pl = abs($days) > 1 ? "s" : "";
             $r = sprintf("%s (%s): %s (%s)",
                          $days == 0 ? "today" :
@@ -147,7 +149,7 @@ sub _process_hl {
                          $ats->datetime->ymd);
             $date = $ats->datetime;
         } else {
-            $r = $hl->title->as_string;
+            chomp($r = $hl->title->as_string);
         }
     }
     push @$res, [$r, $date, $hl];
@@ -206,6 +208,7 @@ _
         detail => {
             schema => [bool => default => 0],
             summary => 'Show details instead of just titles',
+            cmdline_aliases => {l=>{}},
             tags => ['format'],
         },
         has_tags => {
@@ -337,6 +340,7 @@ sub list_org_headlines {
     my $sort  = $args{sort};
     my $tz    = $args{time_zone} // $ENV{TZ} // "UTC";
     my $files = $args{files};
+    $args{_raw} //= 1;
 
     $today = $args{today} // DateTime->today(time_zone => $tz);
 
@@ -352,7 +356,7 @@ sub list_org_headlines {
             sub {
                 my ($el) = @_;
                 return unless $el->isa('Org::Element::Headline');
-                _process_hl($file, $el, \%args, \@res)
+                _process_hl($file, $el, \%args, \@res, $args{_raw})
             });
     }
 
@@ -420,7 +424,7 @@ App::ListOrgHeadlines - List all headlines in all Org files
 
 =head1 VERSION
 
-This document describes version 0.484 of App::ListOrgHeadlines (from Perl distribution App-OrgUtils), released on 2023-01-19.
+This document describes version 0.485 of App::ListOrgHeadlines (from Perl distribution App-OrgUtils), released on 2023-04-06.
 
 =head1 SYNOPSIS
 
